Who Is Using It?
================

These are some projects using this extension
that you can take a look at to understand how they are configured and what's the behavior.

.. Scrensshot images are 700x600

Read the Docs
-------------

|:books:| Repository
   https://github.com/readthedocs/readthedocs.org

|:earth_asia:| Example 404 Not Found page
   https://docs.readthedocs.io/en/stable/not/found.html

|:gear:| Configuration file (``conf.py``)
   https://github.com/readthedocs/readthedocs.org/blob/master/docs/conf.py

|:art:| Screenshot
   .. image:: _static/who-is-using-it/docs.readthedocs.io.png


PyVista
-------

|:books:| Repository
   https://github.com/pyvista/pyvista

|:earth_asia:| Example 404 Not Found page
   https://docs.pyvista.org/not/found/page.html

|:gear:| Configuration file (``conf.py``)
   https://github.com/pyvista/pyvista/blob/master/doc/conf.py

|:art:| Screenshot
   .. image:: _static/who-is-using-it/docs.pyvista.org.png



Write the Docs
--------------

|:books:| Repository
   https://github.com/writethedocs/www

|:earth_asia:| Example 404 Not Found page
   https://www.writethedocs.org/404/

|:gear:| Configuration file (``conf.py``)
   https://github.com/writethedocs/www/blob/master/docs/conf.py

|:art:| Screenshot
   .. image:: _static/who-is-using-it/www.writethedocs.org.png


The Carpentries
---------------

|:books:| Repository
   https://github.com/carpentries/handbook

|:earth_asia:| Example 404 Not Found page
   https://docs.carpentries.org/404/

|:gear:| Configuration file (``conf.py``)
   https://github.com/carpentries/handbook/blob/master/conf.py

|:art:| Screenshot
   .. image:: _static/who-is-using-it/docs.carpentries.org.png


attrs
-----

|:books:| Repository
   https://github.com/python-attrs/attrs

|:earth_asia:| Example 404 Not Found page
   https://www.attrs.org/en/latest/404

|:gear:| Configuration file (``conf.py``)
   https://github.com/python-attrs/attrs/blob/main/docs/conf.py

|:art:| Screenshot
   .. image:: _static/who-is-using-it/www.attrs.org.png


Jina
----

|:books:| Repository
   https://github.com/jina-ai/docs

|:earth_asia:| Example 404 Not Found page
   https://docs.jina.ai/404

|:gear:| Configuration file (``conf.py``)
   https://github.com/jina-ai/docs/blob/master/conf.py

|:art:| Screenshot
   .. image:: _static/who-is-using-it/docs.jina.ai.png


Nengo
-----

|:books:| Repository
   https://github.com/nengo/nengo-sphinx-theme

|:earth_asia:| Example 404 Not Found page
   https://www.nengo.ai/nengo-sphinx-theme/v1.2.2/404

|:gear:| Configuration file (``conf.py``)
   https://github.com/nengo/nengo-sphinx-theme/blob/master/docs/conf.py

|:art:| Screenshot
   .. image:: _static/who-is-using-it/www.nengo.ai.png
